/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvSignalEnvelope.h"
#include "HvMath.h"
#include "HvControlDelay.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_ynZftJ0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_11Uz9IVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KovoXHR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zT0erSbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z3IejloO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l5xB8BFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gbt3BTov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3OrwKrUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_stgzaxSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Sre9JY0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N3UwD0On_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JQTcTRwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9pTKcTdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cNTCIjv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0N0EtDSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qaRB89y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wUOH2jhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QVywKwz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hbQvNNao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pRac2I2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mt8jijgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rode3pVr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ztpO1HUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f5HBQvcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zIY4Pip2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vUAFBewZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ok8Ulif5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZYVYra2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gZJg2rB4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cRJaW830_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XHQggi1y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vfVmZ2ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hqQp56MA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s9HnWSRC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DWRBiMXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cKKdzPws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hl1iYIVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Ysgo63i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kevn8nBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b8EeKzqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_srTa337d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wcZhlIFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iYzEdHkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vARp2J6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hTV4QAWn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lE37PkrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IKBuwuvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_49XpyzgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BQDzmk01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gfmuE3SD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUPEzwkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gLkgcL86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qhRktvQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BwWKdZlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o27a8Me9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_djGFCESi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Jn5ioQFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_12JAJoYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_26PtBZ5d_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_P3blfP0j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hauDz4Qw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rIZr3g0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JWLPuLNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aXPQBGd2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tlCrM6oj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mc7CZsLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cTYM9FD1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aGcTNCZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qzlXEXHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QONuuO5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CQWeXFb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MvCwwhbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dijr5bKf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ulm55TYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2MP7dx5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I4WZurcJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BhZPDbt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MNGjjlY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jw7fbyqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FNzIU7vW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QDyvwNli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UewtOZLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MB176Hrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lU8PE12n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_89EuzqLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QU8U29fM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sRl6Z5W7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_08Z69xcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HZDNX7sc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J0DNVpC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AgXA9Y5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IpKz2tO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I2amdxZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GThoMFeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xIpQMpjQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_na4u1xiR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p4VU1sSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p9VKjf8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sx5ITFj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xB5pYZIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_17ScnibO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_3npYZdPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_evw927tX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cQjPYAw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wQ6MMKOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PWlYqrrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T39MDsST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4d9B9Z1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wBs67QKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZcUuHedQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v5j57ZzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JNHJVFSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ap5D8lpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4y6f0wT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SmIQU7rO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_TR362X4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uw7WICD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kgQKLh2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GxrFTGzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2RHkZIC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uTiOSeQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dySoNKuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xKZsjSLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GQErNVpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_93dKGUgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iaGgQ1jM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tB9aeRxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7vDJlbt9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RgH3ICaU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_gEJPwKEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TXvhqeWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AGb2pI3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sLaFtf10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qGzhpqic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PX19efDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M8uM2FUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AasyYXbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LyN4dd0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yHTlgmse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h8qTuXLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A0sh8ms4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QHPTblGO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_u7c8v1sY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_aNbjZu22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3NYfWzwR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dNxGWcK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZAo50CrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2c4Pl8O0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jWOR8dTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v6sSWGmB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qgnZomSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NCY657jF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HTvVe2Ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZIz4NxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VhSV2oBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o7ZPWd9s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lePCisn2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_BNdFrvAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fo7IKlGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pyjkFKY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CzvGjASR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eusYm94x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GX5Pll42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V0BkJ29k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_io6TpynV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LFp4SeSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eA2bIbOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o8iYADDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_L1qalCCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Wzv5ryYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A2LgAhEJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_45fkWAgl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J9ls03pN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9E3Eo0wY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RQDzxgu1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cWF66BMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HBPy3Hxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X8Di8DIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3BGmoxi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a0pSF8AR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W5ptHDjg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MVnbMRif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gzfIdtSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YRtZyXL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OKpWUm7p_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_0jCSYafg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LH2ngbiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WVT0wmqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lxEfuOs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hufDCl1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z187vCAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CAYzKzjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WwPq9VSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cXqGaoec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QgPKv7VB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h9xhBB0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xt82Ai8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RGrjKZE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mbdcsOFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_thfDbCvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OOpIBUGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_guFkKCYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XmptKamX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yqPlDTxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rlVv5Iuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kWaoEH7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SEriG9hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1QDDxWip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LIlSi96r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CrNledon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lyga7rAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RiveyofL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X81Gdw5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7uWSsco3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qfxeScRt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mHzQb6zG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cz3t8gqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZErizLLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fn0uYouN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwrStXem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CK1yrW0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j57Df0VY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WhTM4ju0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uSvSd3OP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4HW7UTbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aTGnKMlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7uV5mfvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yXj0bVKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_diwoqoXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WRvuDJML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qAb65T1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_71VEKP3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qMwEpyom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hUcdisx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MGcJGczj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c3yjhSwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V5SCNtip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CeHtAiz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KnROQ6zr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6nwN40n5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ywtj2hIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3pdzJqsZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_PtNv4oy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_psrqCXOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YAdCwi8A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8Ph3YUCs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_L2xAv5Ez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kZqhN8h4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V7m80JTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XaFeiifx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Hqc3CRuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lzf1QqXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xjtx7nb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CbmGH7Hh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_a56LZqJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NAgQqYG6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9o3Qu51L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CF0GSTQa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_fDpnAYlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7i6i1rn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q54JVzOp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yHWvQMIw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RXnEn8Ka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EqkP5Gve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9E4OpF9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XUnkVONn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Yt7W8Hq7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OlmzcdF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_SrMgKdaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_K75nNF3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Ed3z6Lw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f1GG8c1d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KHKGS8jI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jjGMCKKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C9z3oap0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VvL4iGcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UX4LjLzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bzoE4Guy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dUnkGJu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M3j2OIis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0vAhTvOp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VVQMP2vL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AJszHWlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gteErx47_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ro27WEz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4hLvIRcd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cbt8VHSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g6l38p9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DWfgN5TR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RkIuoKMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wn9riOSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LDZeMuib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tp3hjdWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hbg5FWE2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8NwwechH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UDUQ3TBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tEhiropk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v0ipbTVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OuSXSTvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DJPxp8eK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TbWNmtjs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_rrpr6jRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cqyuoW8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aEPyKPkp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D3KYjyQt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ph74yBX9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_usSv9PcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_x5gckOgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BlkGhpHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dA8FQrzj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AO7x1Wxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NElhs8ds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fCN8wDUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mL7lGREC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CuOOaLJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aXzxTErv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TvsBN1fc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SBcnJzFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X4bNjdxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NUmDsnkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HBohkxe1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bjUWRar1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_joVMhK1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5ezXBX2O_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_FqgA8NiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_49U3lVtG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yLy0wqpY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wPzwmvCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dBWHi2wA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kp8FmRGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JerA7X1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V8eo0pCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QPkZ0tzA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bH8hu7Q3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wSDCAviD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9WY3FRae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sinKBKwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RAbDepg0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AVxKCygr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SJ3W82I9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ymzsVNka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZEziWnnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cZpTfGyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P0sMv2VZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CXc9obH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ZxcikmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VvHeBtAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BfFeKOC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9lFHQu2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_msUUonbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WTrEEC8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DKUa26yw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_O4KRlpil_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mQLTTQxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cpb1eClo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ve85X1Vu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fG2al0QR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4dLIzbnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O0AEAqJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GrN4X181_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AFK5sXuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_535tCyve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_muMxRiuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7yzJXsrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gD8q3Guo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mwAaPnUh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8GCLyxvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tkiY4BN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sqqFIwbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O5nFDq4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NfnoaXdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MgpHUJmf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mn2cmTaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yiCEswCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z2UDE3OV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bjRv8Rqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SIk7fGVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BMZBSPG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VRRsbLOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5JFpHOR1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_4xA7Qou5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1aNKLJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DCydoLoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DbciiMZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P9Va5IDA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xQTJQjje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BMI2VRRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eMmxx3Xz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wlmmmrUg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_an3vR6w7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PKqDXirk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hTncqOSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eGghKR60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NnIDVQ0g_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_I3pD3sVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1B4V9xTR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1cIW9jRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Huso5UGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DYb6Bydr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dshmMUCH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DCxda5Er_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0lU5p7Ej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xEdjcD0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6l00ThCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rv10b5jG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RNLNhMCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4agFzbhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XKMYmyth_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8GjBP4hU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fYp2t9j9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ftVcnAzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NNzdgz3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vu6hMSfX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WnTNtnPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ao8BRt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hpavn5q0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HZYhYXUU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GuA6diLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4i9l6nCc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wcSkiFz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wq6iySJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jwNC9Rar_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_juCdNvOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mYtun5Lk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SoqORCej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VNU0VcLh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_efC5vPTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rlvgrE6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WTIqniGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7LqiK4L8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9254RVfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8hL75mbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_malGM5Ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_t7JGiEw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lG6eBsRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sC5bMzEO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_a67EWE9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vVjyKCDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lf3hRJAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qYghPMmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KSfnq1Xb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dXcEIopn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HJYSSbly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hK72wbSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NfgPFwAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oWOnLWZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8p2rggdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RWsx8vjT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ISi8Yzwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mhWvTLic_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_EqvycJTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QtxaGpAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OiAjrPbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gelR2OqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQnaeMNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u6ecto69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LtSOV2at_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xQCvBKel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nU9WtNGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K4wLkUii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JWflJuXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Pm4BzFIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YYFdVpQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MZ2g7sIA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_4c9sunoS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6wlgyas3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1ZEvZPCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O8VDM81y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jsSF1NKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FNbUrUgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7X7OXixz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aIRvW2GR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lIyf9WgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8VFpFl95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ebC64Ol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_57KxdGkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5frdf7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fkbqK25o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E8tQPXeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bUmqh8FM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RielqAtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lSCGYkPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_20c7uWj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q5TyL5Wo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JhmDLILL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XeqgMGjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OFOTISRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lsOhB02A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GpMre1JS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W4H7fuXf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ZMPNiGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o34FPlWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pU0RuyVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jz3KMCho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JpKuuBUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SOKmRSpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dDylxgmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EtM2budj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w4YfYncI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gYQGqdOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UfsVV47o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nvmOXaOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q1ZwCACS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iMebcDpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I2YBvRml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QBCEeYJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nl8rCiSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UQepoEw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kkEgmUv5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LBSXaoAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0CSQvZzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6H5urb63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LHOYOJnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qs7AMqh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Id1fK7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Okw2NS6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9dqkso4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZpucFyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y1nSLdLX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YNrkEqiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aVjnT22Q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3Yx18ui9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3N6F7bzr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_74b1HVP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lNPmuCdx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gmhdXCGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4iVch2oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gxumheIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5UcIbECV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aIwl03gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_axjLrkck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MqIQICLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_X48jNBLa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sT5BAJKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r2MNHDOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Bq4KYvtX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kYm5j3EU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_JGs4Emgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rzWDyQPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_d6sGe8Yx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jvxE2Y73_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_HsEB0sGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z9nAKdmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hlRoFTMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NbgD5xPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wdcBE9yG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HbCfEC8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_BTHJuXP0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_QClAbQNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EqCU7oui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XtDe5lwL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sYraAvqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GIWNbutc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vsMPU8pa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oqxxQUxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kl6rssVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bsm0rRln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f0N2Li9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UZD0mMmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T3f6cfIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_elxteTdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q1e6GkDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pQaX4pa5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_nPdf6vDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IDLf15QV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qt7vSm6O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YdIiAruO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6fPE5vhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZGhvDZrV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YqIkClFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n07Zwmnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OaNyGo2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hEK3oEJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k7NRo9mH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HIawRNAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XT3gy7uv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_32cz3ztf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fYIbmL6s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sqdTLqrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xpu7oTvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oT986Z1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hbx1vRBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D85kMQwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EV17TOUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_huO2mIsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gpGVZSae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RE3FSdRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nxffwnRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qz8VA5Xd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_94wd4T6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RrdH3RLI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OUGolVj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AJg2Wury_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sFlkaUBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m9wM2Rt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6TOMJuGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2kswQO91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0a6jxfvE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xjMIS8vk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_srTICXxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DdDHjh20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AR9yh8WE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P8iHgefg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zV4CvCrZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3rJkxyyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gg0dxd8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2I3wBNOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5l8LjfSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Fi8RgYss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PFx7amqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CDdgStOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_usbr9dYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_otXrqjZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DzCKLB3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_xr2n3Ono;
  SignalLine sLine_zD3LEHK2;
  SignalLine sLine_Ap9Kfx9T;
  SignalLine sLine_WyCVlBvR;
  SignalLine sLine_3UjeiHQ0;
  SignalLine sLine_umD1ABUG;
  SignalLine sLine_1v2SddHS;
  SignalLine sLine_E9xA34iD;
  SignalLine sLine_7RJSY5Yx;
  SignalLine sLine_Obkl44kX;
  SignalLine sLine_Jv2aDOis;
  SignalLine sLine_L42a1SSP;
  SignalEnvelope sEnv_SrMgKdaM;
  SignalEnvelope sEnv_K75nNF3w;
  SignalLine sLine_84ssfueA;
  SignalLine sLine_jdmGv1tN;
  SignalLine sLine_H6jt4l6S;
  SignalLine sLine_H6QW7eXl;
  SignalLine sLine_zGTneLW9;
  SignalLine sLine_QKey9Udo;
  SignalLine sLine_R4cAtf1O;
  SignalLine sLine_Dic8yEkl;
  SignalLine sLine_BthAJFM2;
  SignalLine sLine_JpOdmnI9;
  SignalLine sLine_LtHTRDyF;
  SignalLine sLine_pn6ocTEW;
  SignalLine sLine_jxxd0Jyu;
  SignalLine sLine_MKjrVaLX;
  SignalLine sLine_uGgXVsEA;
  SignalLine sLine_LWf0bIHg;
  SignalLine sLine_Go47NcOq;
  SignalLine sLine_eujfKfZP;
  SignalEnvelope sEnv_BTHJuXP0;
  SignalEnvelope sEnv_QClAbQNf;
  SignalLine sLine_8KwYBe3n;
  SignalLine sLine_YUOKFyTx;
  SignalLine sLine_OVB5kjyg;
  SignalLine sLine_L53NvMD7;
  SignalLine sLine_VBmjaAec;
  SignalLine sLine_3HbuJ7Ew;
  SignalLine sLine_w486z1oe;
  SignalLine sLine_Z0rjlaAc;
  ControlVar cVar_ynZftJ0Y;
  ControlBinop cBinop_11Uz9IVd;
  ControlBinop cBinop_KovoXHR7;
  ControlBinop cBinop_zT0erSbH;
  ControlBinop cBinop_Z3IejloO;
  ControlBinop cBinop_3OrwKrUW;
  ControlBinop cBinop_0Sre9JY0;
  ControlBinop cBinop_N3UwD0On;
  ControlBinop cBinop_JQTcTRwj;
  ControlVar cVar_9pTKcTdn;
  ControlVar cVar_cNTCIjv0;
  ControlVar cVar_0N0EtDSy;
  ControlVar cVar_qaRB89y9;
  ControlVar cVar_wUOH2jhH;
  ControlBinop cBinop_QVywKwz6;
  ControlVar cVar_pRac2I2j;
  ControlVar cVar_Mt8jijgB;
  ControlIf cIf_gZJg2rB4;
  ControlIf cIf_cRJaW830;
  ControlDelay cDelay_vfVmZ2ay;
  ControlBinop cBinop_DWRBiMXr;
  ControlBinop cBinop_cKKdzPws;
  ControlIf cIf_iYzEdHkD;
  ControlIf cIf_vARp2J6T;
  ControlDelay cDelay_lE37PkrG;
  ControlBinop cBinop_BQDzmk01;
  ControlBinop cBinop_gfmuE3SD;
  ControlIf cIf_Jn5ioQFU;
  ControlIf cIf_12JAJoYV;
  ControlDelay cDelay_P3blfP0j;
  ControlBinop cBinop_JWLPuLNN;
  ControlBinop cBinop_aXPQBGd2;
  ControlIf cIf_CQWeXFb8;
  ControlIf cIf_MvCwwhbE;
  ControlDelay cDelay_ulm55TYI;
  ControlBinop cBinop_BhZPDbt5;
  ControlBinop cBinop_MNGjjlY6;
  ControlIf cIf_89EuzqLO;
  ControlIf cIf_QU8U29fM;
  ControlDelay cDelay_08Z69xcw;
  ControlBinop cBinop_AgXA9Y5M;
  ControlBinop cBinop_IpKz2tO9;
  ControlIf cIf_sx5ITFj1;
  ControlIf cIf_xB5pYZIp;
  ControlDelay cDelay_3npYZdPh;
  ControlBinop cBinop_wQ6MMKOb;
  ControlBinop cBinop_PWlYqrrQ;
  ControlIf cIf_Ap5D8lpm;
  ControlIf cIf_4y6f0wT9;
  ControlDelay cDelay_TR362X4f;
  ControlBinop cBinop_GxrFTGzY;
  ControlBinop cBinop_2RHkZIC5;
  ControlIf cIf_tB9aeRxi;
  ControlIf cIf_7vDJlbt9;
  ControlDelay cDelay_gEJPwKEm;
  ControlBinop cBinop_sLaFtf10;
  ControlBinop cBinop_qGzhpqic;
  ControlIf cIf_A0sh8ms4;
  ControlIf cIf_QHPTblGO;
  ControlDelay cDelay_aNbjZu22;
  ControlBinop cBinop_ZAo50CrR;
  ControlBinop cBinop_2c4Pl8O0;
  ControlIf cIf_VhSV2oBy;
  ControlIf cIf_o7ZPWd9s;
  ControlDelay cDelay_BNdFrvAC;
  ControlBinop cBinop_CzvGjASR;
  ControlBinop cBinop_eusYm94x;
  ControlIf cIf_L1qalCCO;
  ControlIf cIf_Wzv5ryYh;
  ControlDelay cDelay_45fkWAgl;
  ControlBinop cBinop_RQDzxgu1;
  ControlBinop cBinop_cWF66BMl;
  ControlIf cIf_gzfIdtSC;
  ControlIf cIf_YRtZyXL2;
  ControlDelay cDelay_0jCSYafg;
  ControlBinop cBinop_lxEfuOs6;
  ControlBinop cBinop_hufDCl1j;
  SignalVarf sVarf_l1HRJjwi;
  SignalVarf sVarf_we79Rw1H;
  SignalVarf sVarf_7C85lWxZ;
  SignalVarf sVarf_uCA918hx;
  SignalVarf sVarf_0e2Blriz;
  SignalVarf sVarf_gkQOMHpD;
  SignalVarf sVarf_cN3Ijgri;
  SignalVarf sVarf_PLRyvLby;
  ControlVar cVar_Ywtj2hIU;
  ControlSlice cSlice_PtNv4oy0;
  ControlVar cVar_psrqCXOi;
  ControlSlice cSlice_L2xAv5Ez;
  ControlVar cVar_kZqhN8h4;
  ControlSlice cSlice_Hqc3CRuK;
  ControlVar cVar_lzf1QqXM;
  ControlSlice cSlice_a56LZqJ6;
  ControlVar cVar_NAgQqYG6;
  ControlSlice cSlice_fDpnAYlz;
  ControlVar cVar_7i6i1rn8;
  ControlDelay cDelay_RXnEn8Ka;
  ControlVar cVar_XUnkVONn;
  ControlIf cIf_Yt7W8Hq7;
  ControlIf cIf_OlmzcdF6;
  ControlBinop cBinop_2Ed3z6Lw;
  ControlBinop cBinop_KHKGS8jI;
  ControlBinop cBinop_jjGMCKKA;
  ControlBinop cBinop_UX4LjLzf;
  ControlBinop cBinop_dUnkGJu2;
  ControlSlice cSlice_ro27WEz5;
  ControlVar cVar_4hLvIRcd;
  SignalVarf sVarf_1WFiBjCa;
  SignalVarf sVarf_Md3C2QS2;
  SignalVarf sVarf_0Mng0HRB;
  SignalVarf sVarf_05yqVJiW;
  SignalVarf sVarf_LddU03Hr;
  SignalVarf sVarf_SeyaVrNt;
  ControlBinop cBinop_RkIuoKMO;
  ControlBinop cBinop_tEhiropk;
  ControlVar cVar_OuSXSTvK;
  ControlVar cVar_DJPxp8eK;
  ControlIf cIf_x5gckOgx;
  ControlIf cIf_BlkGhpHS;
  ControlDelay cDelay_AO7x1Wxq;
  ControlBinop cBinop_mL7lGREC;
  ControlBinop cBinop_CuOOaLJq;
  ControlIf cIf_bjUWRar1;
  ControlIf cIf_joVMhK1t;
  ControlDelay cDelay_FqgA8NiH;
  ControlBinop cBinop_wPzwmvCL;
  ControlBinop cBinop_dBWHi2wA;
  ControlIf cIf_9WY3FRae;
  ControlIf cIf_sinKBKwN;
  ControlDelay cDelay_AVxKCygr;
  ControlBinop cBinop_ZEziWnnr;
  ControlBinop cBinop_cZpTfGyp;
  ControlIf cIf_msUUonbg;
  ControlIf cIf_WTrEEC8Z;
  ControlDelay cDelay_O4KRlpil;
  ControlBinop cBinop_Ve85X1Vu;
  ControlBinop cBinop_fG2al0QR;
  ControlIf cIf_7yzJXsrQ;
  ControlIf cIf_gD8q3Guo;
  ControlDelay cDelay_8GCLyxvn;
  ControlBinop cBinop_O5nFDq4j;
  ControlBinop cBinop_NfnoaXdt;
  ControlIf cIf_BMZBSPG1;
  ControlIf cIf_VRRsbLOx;
  ControlDelay cDelay_4xA7Qou5;
  ControlBinop cBinop_DbciiMZW;
  ControlBinop cBinop_P9Va5IDA;
  ControlIf cIf_hTncqOSN;
  ControlIf cIf_eGghKR60;
  ControlDelay cDelay_I3pD3sVS;
  ControlBinop cBinop_Huso5UGn;
  ControlBinop cBinop_DYb6Bydr;
  ControlIf cIf_RNLNhMCs;
  ControlIf cIf_4agFzbhI;
  ControlDelay cDelay_8GjBP4hU;
  ControlBinop cBinop_NNzdgz3D;
  ControlBinop cBinop_Vu6hMSfX;
  ControlIf cIf_wcSkiFz6;
  ControlIf cIf_wq6iySJ0;
  ControlDelay cDelay_juCdNvOL;
  ControlBinop cBinop_VNU0VcLh;
  ControlBinop cBinop_efC5vPTf;
  ControlIf cIf_t7JGiEw0;
  ControlIf cIf_lG6eBsRr;
  ControlDelay cDelay_a67EWE9V;
  ControlBinop cBinop_qYghPMmb;
  ControlBinop cBinop_KSfnq1Xb;
  ControlIf cIf_RWsx8vjT;
  ControlIf cIf_ISi8Yzwk;
  ControlDelay cDelay_EqvycJTQ;
  ControlBinop cBinop_gelR2OqS;
  ControlBinop cBinop_nQnaeMNO;
  ControlIf cIf_Pm4BzFIc;
  ControlIf cIf_YYFdVpQY;
  ControlDelay cDelay_4c9sunoS;
  ControlBinop cBinop_O8VDM81y;
  ControlBinop cBinop_jsSF1NKE;
  SignalVarf sVarf_vDKKgjZW;
  SignalVarf sVarf_wtTCCKwW;
  SignalVarf sVarf_qbDB0AlP;
  SignalVarf sVarf_Vqcjvfsv;
  SignalVarf sVarf_7bY0F87b;
  SignalVarf sVarf_Bxj9QfVZ;
  SignalVarf sVarf_7oG59d2S;
  SignalVarf sVarf_MIumkn2g;
  ControlVar cVar_YNrkEqiL;
  ControlSlice cSlice_3Yx18ui9;
  ControlVar cVar_3N6F7bzr;
  ControlSlice cSlice_gmhdXCGd;
  ControlVar cVar_4iVch2oz;
  ControlSlice cSlice_aIwl03gc;
  ControlVar cVar_axjLrkck;
  ControlSlice cSlice_sT5BAJKN;
  ControlVar cVar_r2MNHDOy;
  ControlSlice cSlice_JGs4Emgg;
  ControlVar cVar_rzWDyQPz;
  ControlDelay cDelay_HsEB0sGc;
  ControlVar cVar_NbgD5xPq;
  ControlIf cIf_wdcBE9yG;
  ControlIf cIf_HbCfEC8c;
  ControlBinop cBinop_EqCU7oui;
  ControlBinop cBinop_sYraAvqt;
  ControlBinop cBinop_GIWNbutc;
  ControlBinop cBinop_kl6rssVT;
  ControlBinop cBinop_f0N2Li9D;
  ControlSlice cSlice_nPdf6vDU;
  ControlVar cVar_IDLf15QV;
  SignalVarf sVarf_IL6VBlRA;
  SignalVarf sVarf_meABgQO2;
  SignalVarf sVarf_ktkxsgr7;
  SignalVarf sVarf_S1czfjv6;
  SignalVarf sVarf_fHs753Nk;
  SignalVarf sVarf_Q0267enL;
  ControlBinop cBinop_ZGhvDZrV;
  ControlBinop cBinop_XT3gy7uv;
  ControlVar cVar_fYIbmL6s;
  SignalVarf sVarf_5iDt6meW;
  SignalVarf sVarf_2vLf1I5J;
  SignalVarf sVarf_ScuV9jfA;
  SignalVarf sVarf_fZFJzsT4;
  ControlBinop cBinop_EV17TOUf;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
