/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_xr2n3Ono);
  numBytes += sLine_init(&sLine_zD3LEHK2);
  numBytes += sLine_init(&sLine_Ap9Kfx9T);
  numBytes += sLine_init(&sLine_WyCVlBvR);
  numBytes += sLine_init(&sLine_3UjeiHQ0);
  numBytes += sLine_init(&sLine_umD1ABUG);
  numBytes += sLine_init(&sLine_1v2SddHS);
  numBytes += sLine_init(&sLine_E9xA34iD);
  numBytes += sLine_init(&sLine_7RJSY5Yx);
  numBytes += sLine_init(&sLine_Obkl44kX);
  numBytes += sLine_init(&sLine_Jv2aDOis);
  numBytes += sLine_init(&sLine_L42a1SSP);
  numBytes += sEnv_init(&sEnv_SrMgKdaM, 512, 256);
  numBytes += sEnv_init(&sEnv_K75nNF3w, 512, 256);
  numBytes += sLine_init(&sLine_84ssfueA);
  numBytes += sLine_init(&sLine_jdmGv1tN);
  numBytes += sLine_init(&sLine_H6jt4l6S);
  numBytes += sLine_init(&sLine_H6QW7eXl);
  numBytes += sLine_init(&sLine_zGTneLW9);
  numBytes += sLine_init(&sLine_QKey9Udo);
  numBytes += sLine_init(&sLine_R4cAtf1O);
  numBytes += sLine_init(&sLine_Dic8yEkl);
  numBytes += sLine_init(&sLine_BthAJFM2);
  numBytes += sLine_init(&sLine_JpOdmnI9);
  numBytes += sLine_init(&sLine_LtHTRDyF);
  numBytes += sLine_init(&sLine_pn6ocTEW);
  numBytes += sLine_init(&sLine_jxxd0Jyu);
  numBytes += sLine_init(&sLine_MKjrVaLX);
  numBytes += sLine_init(&sLine_uGgXVsEA);
  numBytes += sLine_init(&sLine_LWf0bIHg);
  numBytes += sLine_init(&sLine_Go47NcOq);
  numBytes += sLine_init(&sLine_eujfKfZP);
  numBytes += sEnv_init(&sEnv_BTHJuXP0, 512, 256);
  numBytes += sEnv_init(&sEnv_QClAbQNf, 512, 256);
  numBytes += sLine_init(&sLine_8KwYBe3n);
  numBytes += sLine_init(&sLine_YUOKFyTx);
  numBytes += sLine_init(&sLine_OVB5kjyg);
  numBytes += sLine_init(&sLine_L53NvMD7);
  numBytes += sLine_init(&sLine_VBmjaAec);
  numBytes += sLine_init(&sLine_3HbuJ7Ew);
  numBytes += sLine_init(&sLine_w486z1oe);
  numBytes += sLine_init(&sLine_Z0rjlaAc);
  numBytes += cVar_init_f(&cVar_ynZftJ0Y, 0.0f);
  numBytes += cVar_init_f(&cVar_9pTKcTdn, 0.0f);
  numBytes += cVar_init_f(&cVar_cNTCIjv0, 0.0f);
  numBytes += cVar_init_f(&cVar_0N0EtDSy, 0.0f);
  numBytes += cVar_init_f(&cVar_qaRB89y9, 0.0f);
  numBytes += cVar_init_f(&cVar_wUOH2jhH, 1.0f);
  numBytes += cVar_init_f(&cVar_pRac2I2j, 0.0f);
  numBytes += cVar_init_f(&cVar_Mt8jijgB, 0.0f);
  numBytes += cIf_init(&cIf_gZJg2rB4, false);
  numBytes += cIf_init(&cIf_cRJaW830, false);
  numBytes += cDelay_init(this, &cDelay_vfVmZ2ay, 10.0f);
  numBytes += cIf_init(&cIf_iYzEdHkD, false);
  numBytes += cIf_init(&cIf_vARp2J6T, false);
  numBytes += cDelay_init(this, &cDelay_lE37PkrG, 10.0f);
  numBytes += cIf_init(&cIf_Jn5ioQFU, false);
  numBytes += cIf_init(&cIf_12JAJoYV, false);
  numBytes += cDelay_init(this, &cDelay_P3blfP0j, 10.0f);
  numBytes += cIf_init(&cIf_CQWeXFb8, false);
  numBytes += cIf_init(&cIf_MvCwwhbE, false);
  numBytes += cDelay_init(this, &cDelay_ulm55TYI, 10.0f);
  numBytes += cIf_init(&cIf_89EuzqLO, false);
  numBytes += cIf_init(&cIf_QU8U29fM, false);
  numBytes += cDelay_init(this, &cDelay_08Z69xcw, 10.0f);
  numBytes += cIf_init(&cIf_sx5ITFj1, false);
  numBytes += cIf_init(&cIf_xB5pYZIp, false);
  numBytes += cDelay_init(this, &cDelay_3npYZdPh, 10.0f);
  numBytes += cIf_init(&cIf_Ap5D8lpm, false);
  numBytes += cIf_init(&cIf_4y6f0wT9, false);
  numBytes += cDelay_init(this, &cDelay_TR362X4f, 10.0f);
  numBytes += cIf_init(&cIf_tB9aeRxi, false);
  numBytes += cIf_init(&cIf_7vDJlbt9, false);
  numBytes += cDelay_init(this, &cDelay_gEJPwKEm, 10.0f);
  numBytes += cIf_init(&cIf_A0sh8ms4, false);
  numBytes += cIf_init(&cIf_QHPTblGO, false);
  numBytes += cDelay_init(this, &cDelay_aNbjZu22, 10.0f);
  numBytes += cIf_init(&cIf_VhSV2oBy, false);
  numBytes += cIf_init(&cIf_o7ZPWd9s, false);
  numBytes += cDelay_init(this, &cDelay_BNdFrvAC, 10.0f);
  numBytes += cIf_init(&cIf_L1qalCCO, false);
  numBytes += cIf_init(&cIf_Wzv5ryYh, false);
  numBytes += cDelay_init(this, &cDelay_45fkWAgl, 10.0f);
  numBytes += cIf_init(&cIf_gzfIdtSC, false);
  numBytes += cIf_init(&cIf_YRtZyXL2, false);
  numBytes += cDelay_init(this, &cDelay_0jCSYafg, 10.0f);
  numBytes += sVarf_init(&sVarf_l1HRJjwi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_we79Rw1H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7C85lWxZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uCA918hx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0e2Blriz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gkQOMHpD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cN3Ijgri, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PLRyvLby, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Ywtj2hIU, 0.0f);
  numBytes += cSlice_init(&cSlice_PtNv4oy0, 1, -1);
  numBytes += cVar_init_f(&cVar_psrqCXOi, 1.0f);
  numBytes += cSlice_init(&cSlice_L2xAv5Ez, 1, -1);
  numBytes += cVar_init_f(&cVar_kZqhN8h4, 0.0f);
  numBytes += cSlice_init(&cSlice_Hqc3CRuK, 1, -1);
  numBytes += cVar_init_f(&cVar_lzf1QqXM, 512.0f);
  numBytes += cSlice_init(&cSlice_a56LZqJ6, 1, -1);
  numBytes += cVar_init_f(&cVar_NAgQqYG6, 1.0f);
  numBytes += cSlice_init(&cSlice_fDpnAYlz, 1, -1);
  numBytes += cVar_init_f(&cVar_7i6i1rn8, 1.0f);
  numBytes += cDelay_init(this, &cDelay_RXnEn8Ka, 20.0f);
  numBytes += cVar_init_f(&cVar_XUnkVONn, 0.0f);
  numBytes += cIf_init(&cIf_Yt7W8Hq7, false);
  numBytes += cIf_init(&cIf_OlmzcdF6, false);
  numBytes += cBinop_init(&cBinop_2Ed3z6Lw, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_ro27WEz5, 1, -1);
  numBytes += cVar_init_f(&cVar_4hLvIRcd, 0.0f);
  numBytes += sVarf_init(&sVarf_1WFiBjCa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Md3C2QS2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0Mng0HRB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_05yqVJiW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LddU03Hr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SeyaVrNt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OuSXSTvK, 0.0f);
  numBytes += cVar_init_f(&cVar_DJPxp8eK, 0.0f);
  numBytes += cIf_init(&cIf_x5gckOgx, false);
  numBytes += cIf_init(&cIf_BlkGhpHS, false);
  numBytes += cDelay_init(this, &cDelay_AO7x1Wxq, 10.0f);
  numBytes += cIf_init(&cIf_bjUWRar1, false);
  numBytes += cIf_init(&cIf_joVMhK1t, false);
  numBytes += cDelay_init(this, &cDelay_FqgA8NiH, 10.0f);
  numBytes += cIf_init(&cIf_9WY3FRae, false);
  numBytes += cIf_init(&cIf_sinKBKwN, false);
  numBytes += cDelay_init(this, &cDelay_AVxKCygr, 10.0f);
  numBytes += cIf_init(&cIf_msUUonbg, false);
  numBytes += cIf_init(&cIf_WTrEEC8Z, false);
  numBytes += cDelay_init(this, &cDelay_O4KRlpil, 10.0f);
  numBytes += cIf_init(&cIf_7yzJXsrQ, false);
  numBytes += cIf_init(&cIf_gD8q3Guo, false);
  numBytes += cDelay_init(this, &cDelay_8GCLyxvn, 10.0f);
  numBytes += cIf_init(&cIf_BMZBSPG1, false);
  numBytes += cIf_init(&cIf_VRRsbLOx, false);
  numBytes += cDelay_init(this, &cDelay_4xA7Qou5, 10.0f);
  numBytes += cIf_init(&cIf_hTncqOSN, false);
  numBytes += cIf_init(&cIf_eGghKR60, false);
  numBytes += cDelay_init(this, &cDelay_I3pD3sVS, 10.0f);
  numBytes += cIf_init(&cIf_RNLNhMCs, false);
  numBytes += cIf_init(&cIf_4agFzbhI, false);
  numBytes += cDelay_init(this, &cDelay_8GjBP4hU, 10.0f);
  numBytes += cIf_init(&cIf_wcSkiFz6, false);
  numBytes += cIf_init(&cIf_wq6iySJ0, false);
  numBytes += cDelay_init(this, &cDelay_juCdNvOL, 10.0f);
  numBytes += cIf_init(&cIf_t7JGiEw0, false);
  numBytes += cIf_init(&cIf_lG6eBsRr, false);
  numBytes += cDelay_init(this, &cDelay_a67EWE9V, 10.0f);
  numBytes += cIf_init(&cIf_RWsx8vjT, false);
  numBytes += cIf_init(&cIf_ISi8Yzwk, false);
  numBytes += cDelay_init(this, &cDelay_EqvycJTQ, 10.0f);
  numBytes += cIf_init(&cIf_Pm4BzFIc, false);
  numBytes += cIf_init(&cIf_YYFdVpQY, false);
  numBytes += cDelay_init(this, &cDelay_4c9sunoS, 10.0f);
  numBytes += sVarf_init(&sVarf_vDKKgjZW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wtTCCKwW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qbDB0AlP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Vqcjvfsv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7bY0F87b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bxj9QfVZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7oG59d2S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MIumkn2g, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YNrkEqiL, 0.0f);
  numBytes += cSlice_init(&cSlice_3Yx18ui9, 1, -1);
  numBytes += cVar_init_f(&cVar_3N6F7bzr, 1.0f);
  numBytes += cSlice_init(&cSlice_gmhdXCGd, 1, -1);
  numBytes += cVar_init_f(&cVar_4iVch2oz, 0.0f);
  numBytes += cSlice_init(&cSlice_aIwl03gc, 1, -1);
  numBytes += cVar_init_f(&cVar_axjLrkck, 512.0f);
  numBytes += cSlice_init(&cSlice_sT5BAJKN, 1, -1);
  numBytes += cVar_init_f(&cVar_r2MNHDOy, 1.0f);
  numBytes += cSlice_init(&cSlice_JGs4Emgg, 1, -1);
  numBytes += cVar_init_f(&cVar_rzWDyQPz, 1.0f);
  numBytes += cDelay_init(this, &cDelay_HsEB0sGc, 20.0f);
  numBytes += cVar_init_f(&cVar_NbgD5xPq, 0.0f);
  numBytes += cIf_init(&cIf_wdcBE9yG, false);
  numBytes += cIf_init(&cIf_HbCfEC8c, false);
  numBytes += cBinop_init(&cBinop_EqCU7oui, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_nPdf6vDU, 1, -1);
  numBytes += cVar_init_f(&cVar_IDLf15QV, 0.0f);
  numBytes += sVarf_init(&sVarf_IL6VBlRA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_meABgQO2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ktkxsgr7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S1czfjv6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fHs753Nk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q0267enL, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fYIbmL6s, 0.0f);
  numBytes += sVarf_init(&sVarf_5iDt6meW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2vLf1I5J, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ScuV9jfA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fZFJzsT4, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_SrMgKdaM);
  sEnv_free(&sEnv_K75nNF3w);
  sEnv_free(&sEnv_BTHJuXP0);
  sEnv_free(&sEnv_QClAbQNf);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2kswQO91_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_srTICXxS_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DzCKLB3k_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xjMIS8vk_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6TOMJuGs_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DdDHjh20_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m9wM2Rt8_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sFlkaUBW_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zV4CvCrZ_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AR9yh8WE_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2I3wBNOL_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gg0dxd8u_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P8iHgefg_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3rJkxyyL_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PFx7amqy_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5l8LjfSO_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_otXrqjZm_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_usbr9dYU_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fi8RgYss_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CDdgStOs_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0a6jxfvE_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_ynZftJ0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hbx1vRBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_11Uz9IVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KovoXHR7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KovoXHR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_zT0erSbH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zT0erSbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Z3IejloO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Z3IejloO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5xB8BFK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gbt3BTov_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_l5xB8BFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3OrwKrUW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gbt3BTov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_stgzaxSl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_3OrwKrUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_N3UwD0On_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_stgzaxSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0Sre9JY0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0Sre9JY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JQTcTRwj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_N3UwD0On_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sqdTLqrh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_JQTcTRwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xpu7oTvQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_9pTKcTdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oT986Z1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_cNTCIjv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_huO2mIsA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_0N0EtDSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D85kMQwI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_qaRB89y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gpGVZSae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_wUOH2jhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QVywKwz6_sendMessage);
  cMsg_RE3FSdRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_QVywKwz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wUOH2jhH, 1, m, &cVar_wUOH2jhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hbQvNNao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nxffwnRI_sendMessage(_c, 0, m);
  cMsg_Qz8VA5Xd_sendMessage(_c, 0, m);
  cMsg_94wd4T6t_sendMessage(_c, 0, m);
  cMsg_AJg2Wury_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_pRac2I2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g6l38p9j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Mt8jijgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DWfgN5TR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_rode3pVr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ztpO1HUQ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f5HBQvcL_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zIY4Pip2_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vUAFBewZ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ok8Ulif5_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZYVYra2i_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_ztpO1HUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xt82Ai8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_f5HBQvcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RGrjKZE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_zIY4Pip2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mbdcsOFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_vUAFBewZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_thfDbCvs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ok8Ulif5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OOpIBUGW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ZYVYra2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_guFkKCYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_gZJg2rB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wcZhlIFx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_cRJaW830_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_srTa337d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_XHQggi1y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hqQp56MA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hqQp56MA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vfVmZ2ay, 1, m, &cDelay_vfVmZ2ay_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9HnWSRC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vfVmZ2ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vfVmZ2ay, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gZJg2rB4, 0, m, &cIf_gZJg2rB4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hqQp56MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vfVmZ2ay, 0, m, &cDelay_vfVmZ2ay_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_s9HnWSRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vfVmZ2ay, 0, m, &cDelay_vfVmZ2ay_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DWRBiMXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b8EeKzqq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kevn8nBD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cKKdzPws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Ysgo63i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hl1iYIVQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Hl1iYIVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XHQggi1y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_5Ysgo63i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gZJg2rB4, 1, m, &cIf_gZJg2rB4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kevn8nBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cRJaW830, 0, m, &cIf_cRJaW830_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_b8EeKzqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cRJaW830, 1, m, &cIf_cRJaW830_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_srTa337d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WyCVlBvR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wcZhlIFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WyCVlBvR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_iYzEdHkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_djGFCESi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_vARp2J6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o27a8Me9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_hTV4QAWn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IKBuwuvw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IKBuwuvw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lE37PkrG, 1, m, &cDelay_lE37PkrG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_49XpyzgS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lE37PkrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lE37PkrG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iYzEdHkD, 0, m, &cIf_iYzEdHkD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IKBuwuvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lE37PkrG, 0, m, &cDelay_lE37PkrG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_49XpyzgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lE37PkrG, 0, m, &cDelay_lE37PkrG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BQDzmk01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BwWKdZlg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qhRktvQH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gfmuE3SD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gLkgcL86_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UUPEzwkm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UUPEzwkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hTV4QAWn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_gLkgcL86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iYzEdHkD, 1, m, &cIf_iYzEdHkD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qhRktvQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vARp2J6T, 0, m, &cIf_vARp2J6T_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BwWKdZlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vARp2J6T, 1, m, &cIf_vARp2J6T_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o27a8Me9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1v2SddHS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_djGFCESi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1v2SddHS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Jn5ioQFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QONuuO5R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_12JAJoYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qzlXEXHJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_26PtBZ5d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hauDz4Qw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hauDz4Qw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_P3blfP0j, 1, m, &cDelay_P3blfP0j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rIZr3g0G_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_P3blfP0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P3blfP0j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Jn5ioQFU, 0, m, &cIf_Jn5ioQFU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hauDz4Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P3blfP0j, 0, m, &cDelay_P3blfP0j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rIZr3g0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P3blfP0j, 0, m, &cDelay_P3blfP0j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JWLPuLNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aGcTNCZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cTYM9FD1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aXPQBGd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tlCrM6oj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mc7CZsLK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tlCrM6oj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jn5ioQFU, 1, m, &cIf_Jn5ioQFU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Mc7CZsLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_26PtBZ5d_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_cTYM9FD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_12JAJoYV, 0, m, &cIf_12JAJoYV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aGcTNCZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_12JAJoYV, 1, m, &cIf_12JAJoYV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qzlXEXHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Obkl44kX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QONuuO5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Obkl44kX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CQWeXFb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lU8PE12n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_MvCwwhbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MB176Hrk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dijr5bKf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2MP7dx5s_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2MP7dx5s_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ulm55TYI, 1, m, &cDelay_ulm55TYI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I4WZurcJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ulm55TYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ulm55TYI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CQWeXFb8, 0, m, &cIf_CQWeXFb8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2MP7dx5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ulm55TYI, 0, m, &cDelay_ulm55TYI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_I4WZurcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ulm55TYI, 0, m, &cDelay_ulm55TYI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BhZPDbt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UewtOZLk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QDyvwNli_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MNGjjlY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FNzIU7vW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jw7fbyqi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jw7fbyqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dijr5bKf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_FNzIU7vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CQWeXFb8, 1, m, &cIf_CQWeXFb8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QDyvwNli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvCwwhbE, 0, m, &cIf_MvCwwhbE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UewtOZLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvCwwhbE, 1, m, &cIf_MvCwwhbE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MB176Hrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3UjeiHQ0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lU8PE12n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3UjeiHQ0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_89EuzqLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p9VKjf8v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_QU8U29fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p4VU1sSI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_sRl6Z5W7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HZDNX7sc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HZDNX7sc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_08Z69xcw, 1, m, &cDelay_08Z69xcw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J0DNVpC2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_08Z69xcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_08Z69xcw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_89EuzqLO, 0, m, &cIf_89EuzqLO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HZDNX7sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_08Z69xcw, 0, m, &cDelay_08Z69xcw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_J0DNVpC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_08Z69xcw, 0, m, &cDelay_08Z69xcw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AgXA9Y5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_na4u1xiR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xIpQMpjQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IpKz2tO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I2amdxZ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GThoMFeY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_I2amdxZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_89EuzqLO, 1, m, &cIf_89EuzqLO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GThoMFeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sRl6Z5W7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_xIpQMpjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QU8U29fM, 0, m, &cIf_QU8U29fM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_na4u1xiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QU8U29fM, 1, m, &cIf_QU8U29fM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_p4VU1sSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E9xA34iD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_p9VKjf8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E9xA34iD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_sx5ITFj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JNHJVFSZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_xB5pYZIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_v5j57ZzD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_17ScnibO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_evw927tX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_evw927tX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3npYZdPh, 1, m, &cDelay_3npYZdPh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cQjPYAw8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_3npYZdPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3npYZdPh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sx5ITFj1, 0, m, &cIf_sx5ITFj1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_evw927tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3npYZdPh, 0, m, &cDelay_3npYZdPh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cQjPYAw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3npYZdPh, 0, m, &cDelay_3npYZdPh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wQ6MMKOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZcUuHedQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wBs67QKX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PWlYqrrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4d9B9Z1I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T39MDsST_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T39MDsST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_17ScnibO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_4d9B9Z1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sx5ITFj1, 1, m, &cIf_sx5ITFj1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wBs67QKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xB5pYZIp, 0, m, &cIf_xB5pYZIp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZcUuHedQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xB5pYZIp, 1, m, &cIf_xB5pYZIp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_v5j57ZzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jv2aDOis, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_JNHJVFSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jv2aDOis, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Ap5D8lpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iaGgQ1jM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_4y6f0wT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_93dKGUgV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_SmIQU7rO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uw7WICD2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uw7WICD2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TR362X4f, 1, m, &cDelay_TR362X4f_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kgQKLh2H_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_TR362X4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TR362X4f, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ap5D8lpm, 0, m, &cIf_Ap5D8lpm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uw7WICD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TR362X4f, 0, m, &cDelay_TR362X4f_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kgQKLh2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TR362X4f, 0, m, &cDelay_TR362X4f_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GxrFTGzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xKZsjSLD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GQErNVpG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2RHkZIC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uTiOSeQD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dySoNKuC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uTiOSeQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ap5D8lpm, 1, m, &cIf_Ap5D8lpm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dySoNKuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SmIQU7rO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_xKZsjSLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4y6f0wT9, 1, m, &cIf_4y6f0wT9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GQErNVpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4y6f0wT9, 0, m, &cIf_4y6f0wT9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_93dKGUgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_umD1ABUG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iaGgQ1jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_umD1ABUG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tB9aeRxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_h8qTuXLU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7vDJlbt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yHTlgmse_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_RgH3ICaU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TXvhqeWm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TXvhqeWm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gEJPwKEm, 1, m, &cDelay_gEJPwKEm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AGb2pI3k_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_gEJPwKEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gEJPwKEm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tB9aeRxi, 0, m, &cIf_tB9aeRxi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TXvhqeWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gEJPwKEm, 0, m, &cDelay_gEJPwKEm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AGb2pI3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gEJPwKEm, 0, m, &cDelay_gEJPwKEm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sLaFtf10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LyN4dd0z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AasyYXbK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qGzhpqic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PX19efDP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M8uM2FUA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PX19efDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tB9aeRxi, 1, m, &cIf_tB9aeRxi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_M8uM2FUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RgH3ICaU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AasyYXbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7vDJlbt9, 0, m, &cIf_7vDJlbt9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LyN4dd0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7vDJlbt9, 1, m, &cIf_7vDJlbt9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yHTlgmse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7RJSY5Yx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_h8qTuXLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7RJSY5Yx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_A0sh8ms4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BZIz4NxV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_QHPTblGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HTvVe2Ky_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_u7c8v1sY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3NYfWzwR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3NYfWzwR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aNbjZu22, 1, m, &cDelay_aNbjZu22_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dNxGWcK1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_aNbjZu22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aNbjZu22, m);
  cIf_onMessage(_c, &Context(_c)->cIf_A0sh8ms4, 0, m, &cIf_A0sh8ms4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3NYfWzwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aNbjZu22, 0, m, &cDelay_aNbjZu22_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dNxGWcK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aNbjZu22, 0, m, &cDelay_aNbjZu22_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ZAo50CrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NCY657jF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qgnZomSi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2c4Pl8O0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v6sSWGmB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jWOR8dTF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jWOR8dTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u7c8v1sY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_v6sSWGmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A0sh8ms4, 1, m, &cIf_A0sh8ms4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qgnZomSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QHPTblGO, 0, m, &cIf_QHPTblGO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NCY657jF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QHPTblGO, 1, m, &cIf_QHPTblGO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HTvVe2Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L42a1SSP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BZIz4NxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L42a1SSP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_VhSV2oBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o8iYADDp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_o7ZPWd9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eA2bIbOH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_lePCisn2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Fo7IKlGG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Fo7IKlGG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BNdFrvAC, 1, m, &cDelay_BNdFrvAC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pyjkFKY6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_BNdFrvAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BNdFrvAC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VhSV2oBy, 0, m, &cIf_VhSV2oBy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Fo7IKlGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BNdFrvAC, 0, m, &cDelay_BNdFrvAC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pyjkFKY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BNdFrvAC, 0, m, &cDelay_BNdFrvAC_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CzvGjASR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_io6TpynV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LFp4SeSp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eusYm94x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V0BkJ29k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GX5Pll42_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GX5Pll42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lePCisn2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_V0BkJ29k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VhSV2oBy, 1, m, &cIf_VhSV2oBy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_io6TpynV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o7ZPWd9s, 1, m, &cIf_o7ZPWd9s_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LFp4SeSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o7ZPWd9s, 0, m, &cIf_o7ZPWd9s_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eA2bIbOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xr2n3Ono, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_o8iYADDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xr2n3Ono, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_L1qalCCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MVnbMRif_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Wzv5ryYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W5ptHDjg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_A2LgAhEJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_J9ls03pN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_J9ls03pN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_45fkWAgl, 1, m, &cDelay_45fkWAgl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9E3Eo0wY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_45fkWAgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_45fkWAgl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_L1qalCCO, 0, m, &cIf_L1qalCCO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_J9ls03pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_45fkWAgl, 0, m, &cDelay_45fkWAgl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9E3Eo0wY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_45fkWAgl, 0, m, &cDelay_45fkWAgl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RQDzxgu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3BGmoxi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a0pSF8AR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cWF66BMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X8Di8DIp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HBPy3Hxj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HBPy3Hxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_A2LgAhEJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_X8Di8DIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L1qalCCO, 1, m, &cIf_L1qalCCO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3BGmoxi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wzv5ryYh, 1, m, &cIf_Wzv5ryYh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_a0pSF8AR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wzv5ryYh, 0, m, &cIf_Wzv5ryYh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_W5ptHDjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zD3LEHK2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_MVnbMRif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zD3LEHK2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_gzfIdtSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_h9xhBB0A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_YRtZyXL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QgPKv7VB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_OKpWUm7p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LH2ngbiv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LH2ngbiv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0jCSYafg, 1, m, &cDelay_0jCSYafg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WVT0wmqn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_0jCSYafg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0jCSYafg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gzfIdtSC, 0, m, &cIf_gzfIdtSC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LH2ngbiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0jCSYafg, 0, m, &cDelay_0jCSYafg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WVT0wmqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0jCSYafg, 0, m, &cDelay_0jCSYafg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_lxEfuOs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WwPq9VSK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cXqGaoec_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hufDCl1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CAYzKzjn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z187vCAk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z187vCAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OKpWUm7p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CAYzKzjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gzfIdtSC, 1, m, &cIf_gzfIdtSC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WwPq9VSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YRtZyXL2, 1, m, &cIf_YRtZyXL2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cXqGaoec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YRtZyXL2, 0, m, &cIf_YRtZyXL2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QgPKv7VB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ap9Kfx9T, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_h9xhBB0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ap9Kfx9T, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xt82Ai8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_LIlSi96r_sendMessage(_c, 0, m);
  cMsg_fn0uYouN_sendMessage(_c, 0, m);
  cMsg_c3yjhSwQ_sendMessage(_c, 0, m);
  cMsg_diwoqoXO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RGrjKZE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_LIlSi96r_sendMessage(_c, 0, m);
  cMsg_ZErizLLV_sendMessage(_c, 0, m);
  cMsg_V5SCNtip_sendMessage(_c, 0, m);
  cMsg_yXj0bVKm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_mbdcsOFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_CrNledon_sendMessage(_c, 0, m);
  cMsg_ZErizLLV_sendMessage(_c, 0, m);
  cMsg_diwoqoXO_sendMessage(_c, 0, m);
  cMsg_6nwN40n5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_thfDbCvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_CrNledon_sendMessage(_c, 0, m);
  cMsg_cwrStXem_sendMessage(_c, 0, m);
  cMsg_c3yjhSwQ_sendMessage(_c, 0, m);
  cMsg_7uV5mfvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_OOpIBUGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_Lyga7rAw_sendMessage(_c, 0, m);
  cMsg_yXj0bVKm_sendMessage(_c, 0, m);
  cMsg_KnROQ6zr_sendMessage(_c, 0, m);
  cMsg_c3yjhSwQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_guFkKCYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_Lyga7rAw_sendMessage(_c, 0, m);
  cMsg_7uV5mfvu_sendMessage(_c, 0, m);
  cMsg_ZErizLLV_sendMessage(_c, 0, m);
  cMsg_CeHtAiz2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XmptKamX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cKKdzPws_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DWRBiMXr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yqPlDTxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cKKdzPws_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DWRBiMXr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rlVv5Iuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gfmuE3SD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BQDzmk01_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kWaoEH7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gfmuE3SD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BQDzmk01_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SEriG9hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aXPQBGd2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JWLPuLNN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1QDDxWip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aXPQBGd2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JWLPuLNN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LIlSi96r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_XmptKamX_sendMessage(_c, 0, m);
  cMsg_kWaoEH7g_sendMessage(_c, 0, m);
  cMsg_1QDDxWip_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CrNledon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_yqPlDTxL_sendMessage(_c, 0, m);
  cMsg_rlVv5Iuh_sendMessage(_c, 0, m);
  cMsg_1QDDxWip_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Lyga7rAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_yqPlDTxL_sendMessage(_c, 0, m);
  cMsg_kWaoEH7g_sendMessage(_c, 0, m);
  cMsg_SEriG9hy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RiveyofL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MNGjjlY6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BhZPDbt5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_X81Gdw5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MNGjjlY6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BhZPDbt5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7uWSsco3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IpKz2tO9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AgXA9Y5M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qfxeScRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IpKz2tO9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AgXA9Y5M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mHzQb6zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PWlYqrrQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wQ6MMKOb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Cz3t8gqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PWlYqrrQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wQ6MMKOb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZErizLLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_X81Gdw5b_sendMessage(_c, 0, m);
  cMsg_qfxeScRt_sendMessage(_c, 0, m);
  cMsg_Cz3t8gqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fn0uYouN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_X81Gdw5b_sendMessage(_c, 0, m);
  cMsg_7uWSsco3_sendMessage(_c, 0, m);
  cMsg_mHzQb6zG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cwrStXem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_RiveyofL_sendMessage(_c, 0, m);
  cMsg_qfxeScRt_sendMessage(_c, 0, m);
  cMsg_mHzQb6zG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CK1yrW0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eusYm94x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CzvGjASR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_j57Df0VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eusYm94x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CzvGjASR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WhTM4ju0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cWF66BMl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RQDzxgu1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uSvSd3OP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cWF66BMl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RQDzxgu1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4HW7UTbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hufDCl1j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lxEfuOs6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aTGnKMlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hufDCl1j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lxEfuOs6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7uV5mfvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_CK1yrW0T_sendMessage(_c, 0, m);
  cMsg_uSvSd3OP_sendMessage(_c, 0, m);
  cMsg_aTGnKMlg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_yXj0bVKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_j57Df0VY_sendMessage(_c, 0, m);
  cMsg_WhTM4ju0_sendMessage(_c, 0, m);
  cMsg_aTGnKMlg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_diwoqoXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_j57Df0VY_sendMessage(_c, 0, m);
  cMsg_uSvSd3OP_sendMessage(_c, 0, m);
  cMsg_4HW7UTbz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WRvuDJML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2RHkZIC5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GxrFTGzY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qAb65T1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2RHkZIC5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GxrFTGzY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_71VEKP3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qGzhpqic_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sLaFtf10_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qMwEpyom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qGzhpqic_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sLaFtf10_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hUcdisx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2c4Pl8O0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZAo50CrR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MGcJGczj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2c4Pl8O0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZAo50CrR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_c3yjhSwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_qAb65T1e_sendMessage(_c, 0, m);
  cMsg_qMwEpyom_sendMessage(_c, 0, m);
  cMsg_MGcJGczj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_V5SCNtip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_qAb65T1e_sendMessage(_c, 0, m);
  cMsg_71VEKP3M_sendMessage(_c, 0, m);
  cMsg_hUcdisx3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CeHtAiz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_WRvuDJML_sendMessage(_c, 0, m);
  cMsg_71VEKP3M_sendMessage(_c, 0, m);
  cMsg_MGcJGczj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KnROQ6zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_RiveyofL_sendMessage(_c, 0, m);
  cMsg_7uWSsco3_sendMessage(_c, 0, m);
  cMsg_Cz3t8gqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6nwN40n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_WRvuDJML_sendMessage(_c, 0, m);
  cMsg_qMwEpyom_sendMessage(_c, 0, m);
  cMsg_hUcdisx3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Ywtj2hIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wn9riOSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_3pdzJqsZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PtNv4oy0, 0, m, &cSlice_PtNv4oy0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CbmGH7Hh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_PtNv4oy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YAdCwi8A_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YAdCwi8A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_psrqCXOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YAdCwi8A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_YAdCwi8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AR9yh8WE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_8Ph3YUCs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L2xAv5Ez, 0, m, &cSlice_L2xAv5Ez_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XaFeiifx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_L2xAv5Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V7m80JTG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V7m80JTG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_kZqhN8h4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V7m80JTG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_V7m80JTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3rJkxyyL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_XaFeiifx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Hqc3CRuK, 0, m, &cSlice_Hqc3CRuK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3pdzJqsZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Hqc3CRuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xjtx7nb7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xjtx7nb7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_lzf1QqXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xjtx7nb7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_xjtx7nb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zV4CvCrZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CbmGH7Hh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a56LZqJ6, 0, m, &cSlice_a56LZqJ6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CF0GSTQa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_a56LZqJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9o3Qu51L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9o3Qu51L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_NAgQqYG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9o3Qu51L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_9o3Qu51L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P8iHgefg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CF0GSTQa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fDpnAYlz, 0, m, &cSlice_fDpnAYlz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gteErx47_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_fDpnAYlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Q54JVzOp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Q54JVzOp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_7i6i1rn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q54JVzOp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Q54JVzOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gg0dxd8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_yHWvQMIw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EqkP5Gve_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EqkP5Gve_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RXnEn8Ka, 1, m, &cDelay_RXnEn8Ka_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9E4OpF9V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RXnEn8Ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RXnEn8Ka, m);
  cMsg_hbg5FWE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_EqkP5Gve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RXnEn8Ka, 0, m, &cDelay_RXnEn8Ka_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9E4OpF9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RXnEn8Ka, 0, m, &cDelay_RXnEn8Ka_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_XUnkVONn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ed3z6Lw, HV_BINOP_SUBTRACT, 0, m, &cBinop_2Ed3z6Lw_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_Yt7W8Hq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AJszHWlB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_OlmzcdF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AJszHWlB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_SrMgKdaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XUnkVONn, 0, m, &cVar_XUnkVONn_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_K75nNF3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0vAhTvOp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VVQMP2vL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M3j2OIis_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2Ed3z6Lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f1GG8c1d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f1GG8c1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KHKGS8jI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KHKGS8jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dUnkGJu2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jjGMCKKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VvL4iGcR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C9z3oap0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C9z3oap0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bzoE4Guy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_VvL4iGcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yt7W8Hq7, 1, m, &cIf_Yt7W8Hq7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UX4LjLzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OlmzcdF6, 1, m, &cIf_OlmzcdF6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bzoE4Guy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Yt7W8Hq7, 0, m, &cIf_Yt7W8Hq7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dUnkGJu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OlmzcdF6, 0, m, &cIf_OlmzcdF6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_M3j2OIis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XUnkVONn, 0, m, &cVar_XUnkVONn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0vAhTvOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_VVQMP2vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ed3z6Lw, HV_BINOP_SUBTRACT, 1, m, &cBinop_2Ed3z6Lw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AJszHWlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_84ssfueA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_gteErx47_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ro27WEz5, 0, m, &cSlice_ro27WEz5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_ro27WEz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cbt8VHSf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cbt8VHSf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_4hLvIRcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cbt8VHSf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_cbt8VHSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2I3wBNOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_g6l38p9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QKey9Udo, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_DWfgN5TR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H6QW7eXl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_RkIuoKMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mt8jijgB, 0, m, &cVar_Mt8jijgB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Wn9riOSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zGTneLW9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_LDZeMuib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yHWvQMIw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Tp3hjdWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8NwwechH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hbg5FWE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jdmGv1tN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8NwwechH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jdmGv1tN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_UDUQ3TBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_tEhiropk_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tEhiropk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v0ipbTVm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_v0ipbTVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H6jt4l6S, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_OuSXSTvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YdIiAruO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_DJPxp8eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6fPE5vhS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_TbWNmtjs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rrpr6jRj_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cqyuoW8Q_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aEPyKPkp_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D3KYjyQt_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ph74yBX9_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usSv9PcC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_rrpr6jRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_57KxdGkk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_cqyuoW8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g5frdf7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_aEPyKPkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fkbqK25o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_D3KYjyQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E8tQPXeY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ph74yBX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bUmqh8FM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_usSv9PcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RielqAtN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_x5gckOgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HBohkxe1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BlkGhpHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NUmDsnkA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dA8FQrzj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NElhs8ds_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NElhs8ds_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AO7x1Wxq, 1, m, &cDelay_AO7x1Wxq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fCN8wDUA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_AO7x1Wxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AO7x1Wxq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_x5gckOgx, 0, m, &cIf_x5gckOgx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NElhs8ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AO7x1Wxq, 0, m, &cDelay_AO7x1Wxq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fCN8wDUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AO7x1Wxq, 0, m, &cDelay_AO7x1Wxq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mL7lGREC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X4bNjdxb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SBcnJzFw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CuOOaLJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aXzxTErv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TvsBN1fc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aXzxTErv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x5gckOgx, 1, m, &cIf_x5gckOgx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TvsBN1fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dA8FQrzj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_SBcnJzFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BlkGhpHS, 0, m, &cIf_BlkGhpHS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X4bNjdxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BlkGhpHS, 1, m, &cIf_BlkGhpHS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NUmDsnkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JpOdmnI9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HBohkxe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JpOdmnI9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_bjUWRar1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wSDCAviD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_joVMhK1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bH8hu7Q3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5ezXBX2O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_49U3lVtG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_49U3lVtG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FqgA8NiH, 1, m, &cDelay_FqgA8NiH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yLy0wqpY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_FqgA8NiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FqgA8NiH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bjUWRar1, 0, m, &cIf_bjUWRar1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_49U3lVtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FqgA8NiH, 0, m, &cDelay_FqgA8NiH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yLy0wqpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FqgA8NiH, 0, m, &cDelay_FqgA8NiH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wPzwmvCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QPkZ0tzA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V8eo0pCd_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dBWHi2wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kp8FmRGh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JerA7X1v_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kp8FmRGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bjUWRar1, 1, m, &cIf_bjUWRar1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JerA7X1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5ezXBX2O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_V8eo0pCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_joVMhK1t, 0, m, &cIf_joVMhK1t_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QPkZ0tzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_joVMhK1t, 1, m, &cIf_joVMhK1t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bH8hu7Q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jxxd0Jyu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wSDCAviD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jxxd0Jyu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_9WY3FRae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9lFHQu2W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sinKBKwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BfFeKOC1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_RAbDepg0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SJ3W82I9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SJ3W82I9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AVxKCygr, 1, m, &cDelay_AVxKCygr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ymzsVNka_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_AVxKCygr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AVxKCygr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9WY3FRae, 0, m, &cIf_9WY3FRae_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SJ3W82I9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AVxKCygr, 0, m, &cDelay_AVxKCygr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ymzsVNka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AVxKCygr, 0, m, &cDelay_AVxKCygr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ZEziWnnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VvHeBtAB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ZxcikmG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cZpTfGyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CXc9obH0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P0sMv2VZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_P0sMv2VZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RAbDepg0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CXc9obH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9WY3FRae, 1, m, &cIf_9WY3FRae_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4ZxcikmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sinKBKwN, 0, m, &cIf_sinKBKwN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VvHeBtAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sinKBKwN, 1, m, &cIf_sinKBKwN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BfFeKOC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LWf0bIHg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9lFHQu2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LWf0bIHg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_msUUonbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_muMxRiuV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_WTrEEC8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_535tCyve_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_DKUa26yw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mQLTTQxa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mQLTTQxa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_O4KRlpil, 1, m, &cDelay_O4KRlpil_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cpb1eClo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_O4KRlpil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O4KRlpil, m);
  cIf_onMessage(_c, &Context(_c)->cIf_msUUonbg, 0, m, &cIf_msUUonbg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mQLTTQxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_O4KRlpil, 0, m, &cDelay_O4KRlpil_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cpb1eClo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_O4KRlpil, 0, m, &cDelay_O4KRlpil_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ve85X1Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AFK5sXuz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GrN4X181_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fG2al0QR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O0AEAqJy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dLIzbnE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4dLIzbnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DKUa26yw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_O0AEAqJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_msUUonbg, 1, m, &cIf_msUUonbg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GrN4X181_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WTrEEC8Z, 0, m, &cIf_WTrEEC8Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AFK5sXuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WTrEEC8Z, 1, m, &cIf_WTrEEC8Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_535tCyve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LtHTRDyF, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_muMxRiuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LtHTRDyF, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7yzJXsrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SIk7fGVD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gD8q3Guo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bjRv8Rqz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_mwAaPnUh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tkiY4BN3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tkiY4BN3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8GCLyxvn, 1, m, &cDelay_8GCLyxvn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sqqFIwbP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8GCLyxvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8GCLyxvn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7yzJXsrQ, 0, m, &cIf_7yzJXsrQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tkiY4BN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8GCLyxvn, 0, m, &cDelay_8GCLyxvn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sqqFIwbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8GCLyxvn, 0, m, &cDelay_8GCLyxvn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_O5nFDq4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z2UDE3OV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yiCEswCh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NfnoaXdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mn2cmTaF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MgpHUJmf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MgpHUJmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mwAaPnUh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_mn2cmTaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7yzJXsrQ, 1, m, &cIf_7yzJXsrQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yiCEswCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gD8q3Guo, 0, m, &cIf_gD8q3Guo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z2UDE3OV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gD8q3Guo, 1, m, &cIf_gD8q3Guo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bjRv8Rqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MKjrVaLX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_SIk7fGVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MKjrVaLX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_BMZBSPG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PKqDXirk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_VRRsbLOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_an3vR6w7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5JFpHOR1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_o1aNKLJF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_o1aNKLJF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4xA7Qou5, 1, m, &cDelay_4xA7Qou5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DCydoLoq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4xA7Qou5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4xA7Qou5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BMZBSPG1, 0, m, &cIf_BMZBSPG1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o1aNKLJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4xA7Qou5, 0, m, &cDelay_4xA7Qou5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DCydoLoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4xA7Qou5, 0, m, &cDelay_4xA7Qou5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DbciiMZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eMmxx3Xz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wlmmmrUg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_P9Va5IDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BMI2VRRp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xQTJQjje_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xQTJQjje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5JFpHOR1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_BMI2VRRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BMZBSPG1, 1, m, &cIf_BMZBSPG1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eMmxx3Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VRRsbLOx, 1, m, &cIf_VRRsbLOx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wlmmmrUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VRRsbLOx, 0, m, &cIf_VRRsbLOx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_an3vR6w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Go47NcOq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PKqDXirk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Go47NcOq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_hTncqOSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Rv10b5jG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_eGghKR60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6l00ThCM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_NnIDVQ0g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1B4V9xTR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1B4V9xTR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I3pD3sVS, 1, m, &cDelay_I3pD3sVS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1cIW9jRE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_I3pD3sVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I3pD3sVS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hTncqOSN, 0, m, &cIf_hTncqOSN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1B4V9xTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I3pD3sVS, 0, m, &cDelay_I3pD3sVS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1cIW9jRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I3pD3sVS, 0, m, &cDelay_I3pD3sVS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Huso5UGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0lU5p7Ej_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xEdjcD0l_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DYb6Bydr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DCxda5Er_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dshmMUCH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dshmMUCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NnIDVQ0g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_DCxda5Er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hTncqOSN, 1, m, &cIf_hTncqOSN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0lU5p7Ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eGghKR60, 1, m, &cIf_eGghKR60_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xEdjcD0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eGghKR60, 0, m, &cIf_eGghKR60_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6l00ThCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pn6ocTEW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Rv10b5jG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pn6ocTEW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_RNLNhMCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4i9l6nCc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_4agFzbhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GuA6diLf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_XKMYmyth_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fYp2t9j9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fYp2t9j9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8GjBP4hU, 1, m, &cDelay_8GjBP4hU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ftVcnAzv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8GjBP4hU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8GjBP4hU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RNLNhMCs, 0, m, &cIf_RNLNhMCs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fYp2t9j9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8GjBP4hU, 0, m, &cDelay_8GjBP4hU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ftVcnAzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8GjBP4hU, 0, m, &cDelay_8GjBP4hU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NNzdgz3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hpavn5q0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HZYhYXUU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Vu6hMSfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ao8BRt4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WnTNtnPJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WnTNtnPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XKMYmyth_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_2ao8BRt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RNLNhMCs, 1, m, &cIf_RNLNhMCs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hpavn5q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4agFzbhI, 1, m, &cIf_4agFzbhI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HZYhYXUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4agFzbhI, 0, m, &cIf_4agFzbhI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GuA6diLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uGgXVsEA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4i9l6nCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uGgXVsEA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_wcSkiFz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_malGM5Ay_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_wq6iySJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8hL75mbv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_jwNC9Rar_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mYtun5Lk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mYtun5Lk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_juCdNvOL, 1, m, &cDelay_juCdNvOL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SoqORCej_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_juCdNvOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_juCdNvOL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wcSkiFz6, 0, m, &cIf_wcSkiFz6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mYtun5Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_juCdNvOL, 0, m, &cDelay_juCdNvOL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SoqORCej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_juCdNvOL, 0, m, &cDelay_juCdNvOL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VNU0VcLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9254RVfK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7LqiK4L8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_efC5vPTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WTIqniGt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rlvgrE6V_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rlvgrE6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jwNC9Rar_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_WTIqniGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wcSkiFz6, 1, m, &cIf_wcSkiFz6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7LqiK4L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wq6iySJ0, 0, m, &cIf_wq6iySJ0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9254RVfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wq6iySJ0, 1, m, &cIf_wq6iySJ0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8hL75mbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eujfKfZP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_malGM5Ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eujfKfZP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_t7JGiEw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8p2rggdC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_lG6eBsRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oWOnLWZY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_sC5bMzEO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vVjyKCDZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vVjyKCDZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_a67EWE9V, 1, m, &cDelay_a67EWE9V_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lf3hRJAC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_a67EWE9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a67EWE9V, m);
  cIf_onMessage(_c, &Context(_c)->cIf_t7JGiEw0, 0, m, &cIf_t7JGiEw0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vVjyKCDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_a67EWE9V, 0, m, &cDelay_a67EWE9V_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lf3hRJAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a67EWE9V, 0, m, &cDelay_a67EWE9V_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qYghPMmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NfgPFwAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hK72wbSt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KSfnq1Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HJYSSbly_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dXcEIopn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dXcEIopn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sC5bMzEO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_HJYSSbly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t7JGiEw0, 1, m, &cIf_t7JGiEw0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hK72wbSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lG6eBsRr, 0, m, &cIf_lG6eBsRr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NfgPFwAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lG6eBsRr, 1, m, &cIf_lG6eBsRr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oWOnLWZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R4cAtf1O, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8p2rggdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R4cAtf1O, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_RWsx8vjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JWflJuXd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ISi8Yzwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_K4wLkUii_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_mhWvTLic_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QtxaGpAe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QtxaGpAe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EqvycJTQ, 1, m, &cDelay_EqvycJTQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OiAjrPbP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_EqvycJTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EqvycJTQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RWsx8vjT, 0, m, &cIf_RWsx8vjT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QtxaGpAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EqvycJTQ, 0, m, &cDelay_EqvycJTQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OiAjrPbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EqvycJTQ, 0, m, &cDelay_EqvycJTQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gelR2OqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nU9WtNGQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xQCvBKel_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nQnaeMNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LtSOV2at_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u6ecto69_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_u6ecto69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mhWvTLic_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_LtSOV2at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWsx8vjT, 1, m, &cIf_RWsx8vjT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xQCvBKel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ISi8Yzwk, 0, m, &cIf_ISi8Yzwk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nU9WtNGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ISi8Yzwk, 1, m, &cIf_ISi8Yzwk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_K4wLkUii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dic8yEkl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_JWflJuXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dic8yEkl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Pm4BzFIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1ebC64Ol_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_YYFdVpQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8VFpFl95_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_MZ2g7sIA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6wlgyas3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6wlgyas3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4c9sunoS, 1, m, &cDelay_4c9sunoS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ZEvZPCv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4c9sunoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4c9sunoS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Pm4BzFIc, 0, m, &cIf_Pm4BzFIc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6wlgyas3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4c9sunoS, 0, m, &cDelay_4c9sunoS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1ZEvZPCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4c9sunoS, 0, m, &cDelay_4c9sunoS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_O8VDM81y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lIyf9WgC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aIRvW2GR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jsSF1NKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7X7OXixz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FNbUrUgj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FNbUrUgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MZ2g7sIA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_7X7OXixz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Pm4BzFIc, 1, m, &cIf_Pm4BzFIc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aIRvW2GR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YYFdVpQY, 0, m, &cIf_YYFdVpQY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lIyf9WgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YYFdVpQY, 1, m, &cIf_YYFdVpQY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8VFpFl95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BthAJFM2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_1ebC64Ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BthAJFM2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_57KxdGkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_lsOhB02A_sendMessage(_c, 0, m);
  cMsg_EtM2budj_sendMessage(_c, 0, m);
  cMsg_3Id1fK7y_sendMessage(_c, 0, m);
  cMsg_UQepoEw0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_g5frdf7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_lsOhB02A_sendMessage(_c, 0, m);
  cMsg_dDylxgmZ_sendMessage(_c, 0, m);
  cMsg_Okw2NS6k_sendMessage(_c, 0, m);
  cMsg_Nl8rCiSr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fkbqK25o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_GpMre1JS_sendMessage(_c, 0, m);
  cMsg_dDylxgmZ_sendMessage(_c, 0, m);
  cMsg_UQepoEw0_sendMessage(_c, 0, m);
  cMsg_Y1nSLdLX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_E8tQPXeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_GpMre1JS_sendMessage(_c, 0, m);
  cMsg_w4YfYncI_sendMessage(_c, 0, m);
  cMsg_3Id1fK7y_sendMessage(_c, 0, m);
  cMsg_QBCEeYJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bUmqh8FM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_W4H7fuXf_sendMessage(_c, 0, m);
  cMsg_Nl8rCiSr_sendMessage(_c, 0, m);
  cMsg_BZpucFyD_sendMessage(_c, 0, m);
  cMsg_3Id1fK7y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RielqAtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_W4H7fuXf_sendMessage(_c, 0, m);
  cMsg_QBCEeYJh_sendMessage(_c, 0, m);
  cMsg_dDylxgmZ_sendMessage(_c, 0, m);
  cMsg_9dqkso4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lSCGYkPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CuOOaLJq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mL7lGREC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_20c7uWj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CuOOaLJq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mL7lGREC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_q5TyL5Wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dBWHi2wA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wPzwmvCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JhmDLILL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dBWHi2wA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wPzwmvCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XeqgMGjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cZpTfGyp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZEziWnnr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OFOTISRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cZpTfGyp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZEziWnnr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lsOhB02A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_lSCGYkPc_sendMessage(_c, 0, m);
  cMsg_JhmDLILL_sendMessage(_c, 0, m);
  cMsg_OFOTISRY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_GpMre1JS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_20c7uWj5_sendMessage(_c, 0, m);
  cMsg_q5TyL5Wo_sendMessage(_c, 0, m);
  cMsg_OFOTISRY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_W4H7fuXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_20c7uWj5_sendMessage(_c, 0, m);
  cMsg_JhmDLILL_sendMessage(_c, 0, m);
  cMsg_XeqgMGjs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8ZMPNiGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fG2al0QR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ve85X1Vu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o34FPlWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fG2al0QR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ve85X1Vu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pU0RuyVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NfnoaXdt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O5nFDq4j_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Jz3KMCho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NfnoaXdt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O5nFDq4j_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JpKuuBUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P9Va5IDA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DbciiMZW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SOKmRSpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P9Va5IDA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DbciiMZW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dDylxgmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_o34FPlWx_sendMessage(_c, 0, m);
  cMsg_Jz3KMCho_sendMessage(_c, 0, m);
  cMsg_SOKmRSpU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_EtM2budj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_o34FPlWx_sendMessage(_c, 0, m);
  cMsg_pU0RuyVJ_sendMessage(_c, 0, m);
  cMsg_JpKuuBUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_w4YfYncI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_8ZMPNiGR_sendMessage(_c, 0, m);
  cMsg_Jz3KMCho_sendMessage(_c, 0, m);
  cMsg_JpKuuBUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gYQGqdOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KSfnq1Xb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qYghPMmb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UfsVV47o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KSfnq1Xb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qYghPMmb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nvmOXaOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nQnaeMNO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gelR2OqS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Q1ZwCACS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nQnaeMNO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gelR2OqS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iMebcDpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jsSF1NKE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O8VDM81y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_I2YBvRml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jsSF1NKE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O8VDM81y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QBCEeYJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_gYQGqdOe_sendMessage(_c, 0, m);
  cMsg_Q1ZwCACS_sendMessage(_c, 0, m);
  cMsg_I2YBvRml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Nl8rCiSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_UfsVV47o_sendMessage(_c, 0, m);
  cMsg_nvmOXaOE_sendMessage(_c, 0, m);
  cMsg_I2YBvRml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UQepoEw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_UfsVV47o_sendMessage(_c, 0, m);
  cMsg_Q1ZwCACS_sendMessage(_c, 0, m);
  cMsg_iMebcDpe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kkEgmUv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DYb6Bydr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Huso5UGn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LBSXaoAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DYb6Bydr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Huso5UGn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0CSQvZzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vu6hMSfX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NNzdgz3D_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6H5urb63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vu6hMSfX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NNzdgz3D_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LHOYOJnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_efC5vPTf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VNU0VcLh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Qs7AMqh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_efC5vPTf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VNU0VcLh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3Id1fK7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_LBSXaoAW_sendMessage(_c, 0, m);
  cMsg_6H5urb63_sendMessage(_c, 0, m);
  cMsg_Qs7AMqh4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Okw2NS6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_LBSXaoAW_sendMessage(_c, 0, m);
  cMsg_0CSQvZzq_sendMessage(_c, 0, m);
  cMsg_LHOYOJnp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9dqkso4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_kkEgmUv5_sendMessage(_c, 0, m);
  cMsg_0CSQvZzq_sendMessage(_c, 0, m);
  cMsg_Qs7AMqh4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BZpucFyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_8ZMPNiGR_sendMessage(_c, 0, m);
  cMsg_pU0RuyVJ_sendMessage(_c, 0, m);
  cMsg_SOKmRSpU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Y1nSLdLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_kkEgmUv5_sendMessage(_c, 0, m);
  cMsg_6H5urb63_sendMessage(_c, 0, m);
  cMsg_LHOYOJnp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_YNrkEqiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YqIkClFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_aVjnT22Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3Yx18ui9, 0, m, &cSlice_3Yx18ui9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_X48jNBLa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_3Yx18ui9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_74b1HVP5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_74b1HVP5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_3N6F7bzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_74b1HVP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_74b1HVP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5l8LjfSO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_lNPmuCdx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gmhdXCGd, 0, m, &cSlice_gmhdXCGd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5UcIbECV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_gmhdXCGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gxumheIq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gxumheIq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_4iVch2oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gxumheIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_gxumheIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CDdgStOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_5UcIbECV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aIwl03gc, 0, m, &cSlice_aIwl03gc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aVjnT22Q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_aIwl03gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MqIQICLs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MqIQICLs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_axjLrkck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MqIQICLs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_MqIQICLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PFx7amqy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_X48jNBLa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sT5BAJKN, 0, m, &cSlice_sT5BAJKN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kYm5j3EU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_sT5BAJKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Bq4KYvtX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Bq4KYvtX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_r2MNHDOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Bq4KYvtX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Bq4KYvtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Fi8RgYss_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_kYm5j3EU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JGs4Emgg, 0, m, &cSlice_JGs4Emgg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pQaX4pa5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_JGs4Emgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_d6sGe8Yx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_d6sGe8Yx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_rzWDyQPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d6sGe8Yx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_d6sGe8Yx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_usbr9dYU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_jvxE2Y73_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Z9nAKdmX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Z9nAKdmX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HsEB0sGc, 1, m, &cDelay_HsEB0sGc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hlRoFTMI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_HsEB0sGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HsEB0sGc, m);
  cMsg_hEK3oEJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Z9nAKdmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HsEB0sGc, 0, m, &cDelay_HsEB0sGc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hlRoFTMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HsEB0sGc, 0, m, &cDelay_HsEB0sGc_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_NbgD5xPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EqCU7oui, HV_BINOP_SUBTRACT, 0, m, &cBinop_EqCU7oui_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_wdcBE9yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q1e6GkDW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_HbCfEC8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q1e6GkDW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_BTHJuXP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NbgD5xPq, 0, m, &cVar_NbgD5xPq_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_QClAbQNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T3f6cfIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UZD0mMmq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_elxteTdo_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EqCU7oui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XtDe5lwL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XtDe5lwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sYraAvqt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sYraAvqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_f0N2Li9D_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GIWNbutc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vsMPU8pa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oqxxQUxN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vsMPU8pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wdcBE9yG, 1, m, &cIf_wdcBE9yG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oqxxQUxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bsm0rRln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_kl6rssVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HbCfEC8c, 1, m, &cIf_HbCfEC8c_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bsm0rRln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_wdcBE9yG, 0, m, &cIf_wdcBE9yG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_f0N2Li9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HbCfEC8c, 0, m, &cIf_HbCfEC8c_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UZD0mMmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EqCU7oui, HV_BINOP_SUBTRACT, 1, m, &cBinop_EqCU7oui_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T3f6cfIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_elxteTdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NbgD5xPq, 0, m, &cVar_NbgD5xPq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Q1e6GkDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8KwYBe3n, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_pQaX4pa5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nPdf6vDU, 0, m, &cSlice_nPdf6vDU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_nPdf6vDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qt7vSm6O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qt7vSm6O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_IDLf15QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qt7vSm6O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_qt7vSm6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_otXrqjZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_YdIiAruO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3HbuJ7Ew, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_6fPE5vhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L53NvMD7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_ZGhvDZrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DJPxp8eK, 0, m, &cVar_DJPxp8eK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YqIkClFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VBmjaAec, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_n07Zwmnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jvxE2Y73_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OaNyGo2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k7NRo9mH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hEK3oEJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YUOKFyTx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_k7NRo9mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YUOKFyTx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HIawRNAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_XT3gy7uv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XT3gy7uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_32cz3ztf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_32cz3ztf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OVB5kjyg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_fYIbmL6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OUGolVj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sqdTLqrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z0rjlaAc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Xpu7oTvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w486z1oe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_oT986Z1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sFlkaUBW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hbx1vRBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Ph3YUCs_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lNPmuCdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_D85kMQwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Ph3YUCs_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lNPmuCdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_EV17TOUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9pTKcTdn, 0, m, &cVar_9pTKcTdn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_huO2mIsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Ph3YUCs_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lNPmuCdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gpGVZSae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Ph3YUCs_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lNPmuCdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_RE3FSdRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Ph3YUCs_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lNPmuCdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nxffwnRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0N0EtDSy, 0, m, &cVar_0N0EtDSy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Qz8VA5Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cNTCIjv0, 0, m, &cVar_cNTCIjv0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qaRB89y9, 0, m, &cVar_qaRB89y9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_94wd4T6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_EV17TOUf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RrdH3RLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wUOH2jhH, 0, m, &cVar_wUOH2jhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OUGolVj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Ph3YUCs_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lNPmuCdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AJg2Wury_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_fYIbmL6s, 0, m, &cVar_fYIbmL6s_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_sFlkaUBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_11Uz9IVd_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_m9wM2Rt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ynZftJ0Y, 0, m, &cVar_ynZftJ0Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6TOMJuGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_EV17TOUf_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_2kswQO91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0N0EtDSy, 0, m, &cVar_0N0EtDSy_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_0a6jxfvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_psrqCXOi, 0, m, &cVar_psrqCXOi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kZqhN8h4, 0, m, &cVar_kZqhN8h4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lzf1QqXM, 0, m, &cVar_lzf1QqXM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NAgQqYG6, 0, m, &cVar_NAgQqYG6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7i6i1rn8, 0, m, &cVar_7i6i1rn8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4hLvIRcd, 0, m, &cVar_4hLvIRcd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3N6F7bzr, 0, m, &cVar_3N6F7bzr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4iVch2oz, 0, m, &cVar_4iVch2oz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_axjLrkck, 0, m, &cVar_axjLrkck_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_r2MNHDOy, 0, m, &cVar_r2MNHDOy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rzWDyQPz, 0, m, &cVar_rzWDyQPz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IDLf15QV, 0, m, &cVar_IDLf15QV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hbQvNNao_sendMessage);
  cMsg_RrdH3RLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_xjMIS8vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wUOH2jhH, 0, m, &cVar_wUOH2jhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_srTICXxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cNTCIjv0, 0, m, &cVar_cNTCIjv0_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_DdDHjh20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qaRB89y9, 0, m, &cVar_qaRB89y9_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_AR9yh8WE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pRac2I2j, 0, m, &cVar_pRac2I2j_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_P8iHgefg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ywtj2hIU, 0, m, &cVar_Ywtj2hIU_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_zV4CvCrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_RkIuoKMO_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3rJkxyyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rode3pVr_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tp3hjdWy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDZeMuib_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_gg0dxd8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jjGMCKKA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UX4LjLzf_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_2I3wBNOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UDUQ3TBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_5l8LjfSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OuSXSTvK, 0, m, &cVar_OuSXSTvK_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Fi8RgYss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YNrkEqiL, 0, m, &cVar_YNrkEqiL_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_PFx7amqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ZGhvDZrV_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_CDdgStOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TbWNmtjs_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OaNyGo2W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n07Zwmnd_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_usbr9dYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GIWNbutc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kl6rssVT_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_otXrqjZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HIawRNAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_DzCKLB3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fYIbmL6s, 0, m, &cVar_fYIbmL6s_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_5iDt6meW, VIf(I0));
    __hv_varread_f(&sVarf_1WFiBjCa, VOf(Bf0));
    __hv_varread_f(&sVarf_SeyaVrNt, VOf(Bf1));
    __hv_varread_f(&sVarf_LddU03Hr, VOf(Bf2));
    __hv_varread_f(&sVarf_we79Rw1H, VOf(Bf3));
    __hv_varread_f(&sVarf_7C85lWxZ, VOf(Bf4));
    __hv_varread_f(&sVarf_uCA918hx, VOf(Bf5));
    __hv_varread_f(&sVarf_0e2Blriz, VOf(Bf6));
    __hv_varwrite_f(&sVarf_l1HRJjwi, VIf(I0));
    __hv_varread_f(&sVarf_gkQOMHpD, VOf(Bf7));
    __hv_line_f(&sLine_xr2n3Ono, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_cN3Ijgri, VOf(Bf9));
    __hv_line_f(&sLine_zD3LEHK2, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_PLRyvLby, VOf(Bf8));
    __hv_line_f(&sLine_Ap9Kfx9T, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_we79Rw1H, VIf(Bf11));
    __hv_varread_f(&sVarf_l1HRJjwi, VOf(Bf11));
    __hv_line_f(&sLine_WyCVlBvR, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_3UjeiHQ0, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_umD1ABUG, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_7C85lWxZ, VIf(Bf10));
    __hv_line_f(&sLine_1v2SddHS, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_E9xA34iD, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_7RJSY5Yx, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_uCA918hx, VIf(Bf10));
    __hv_line_f(&sLine_Obkl44kX, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_Jv2aDOis, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_L42a1SSP, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_0e2Blriz, VIf(Bf10));
    __hv_varwrite_f(&sVarf_gkQOMHpD, VIf(Bf0));
    __hv_varwrite_f(&sVarf_cN3Ijgri, VIf(Bf1));
    __hv_varwrite_f(&sVarf_PLRyvLby, VIf(Bf2));
    sEnv_process(this, &sEnv_SrMgKdaM, VIf(Bf3), &sEnv_SrMgKdaM_sendMessage);
    sEnv_process(this, &sEnv_K75nNF3w, VIf(I0), &sEnv_K75nNF3w_sendMessage);
    __hv_line_f(&sLine_84ssfueA, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_jdmGv1tN, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_H6jt4l6S, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Md3C2QS2, VOf(Bf3));
    __hv_line_f(&sLine_H6QW7eXl, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_1WFiBjCa, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Md3C2QS2, VIf(Bf4));
    __hv_varwrite_f(&sVarf_0Mng0HRB, VIf(Bf5));
    __hv_varwrite_f(&sVarf_05yqVJiW, VIf(Bf6));
    __hv_varread_f(&sVarf_05yqVJiW, VOf(Bf6));
    __hv_line_f(&sLine_zGTneLW9, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_LddU03Hr, VIf(Bf4));
    __hv_varread_f(&sVarf_0Mng0HRB, VOf(Bf4));
    __hv_line_f(&sLine_QKey9Udo, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_SeyaVrNt, VIf(Bf4));
    __hv_varwrite_f(&sVarf_2vLf1I5J, VIf(Bf2));
    __hv_varwrite_f(&sVarf_ScuV9jfA, VIf(I1));
    __hv_varread_f(&sVarf_IL6VBlRA, VOf(Bf2));
    __hv_varread_f(&sVarf_Q0267enL, VOf(Bf4));
    __hv_varread_f(&sVarf_fHs753Nk, VOf(Bf0));
    __hv_varread_f(&sVarf_wtTCCKwW, VOf(Bf5));
    __hv_varread_f(&sVarf_qbDB0AlP, VOf(Bf3));
    __hv_varread_f(&sVarf_Vqcjvfsv, VOf(Bf6));
    __hv_varread_f(&sVarf_7bY0F87b, VOf(Bf1));
    __hv_varwrite_f(&sVarf_vDKKgjZW, VIf(I1));
    __hv_varread_f(&sVarf_Bxj9QfVZ, VOf(Bf10));
    __hv_line_f(&sLine_R4cAtf1O, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_7oG59d2S, VOf(Bf7));
    __hv_line_f(&sLine_Dic8yEkl, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_MIumkn2g, VOf(Bf11));
    __hv_line_f(&sLine_BthAJFM2, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_wtTCCKwW, VIf(Bf12));
    __hv_varread_f(&sVarf_vDKKgjZW, VOf(Bf12));
    __hv_line_f(&sLine_JpOdmnI9, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_LtHTRDyF, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_pn6ocTEW, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_qbDB0AlP, VIf(Bf9));
    __hv_line_f(&sLine_jxxd0Jyu, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_MKjrVaLX, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_uGgXVsEA, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_Vqcjvfsv, VIf(Bf9));
    __hv_line_f(&sLine_LWf0bIHg, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_Go47NcOq, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_eujfKfZP, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_7bY0F87b, VIf(Bf9));
    __hv_varwrite_f(&sVarf_Bxj9QfVZ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_7oG59d2S, VIf(Bf4));
    __hv_varwrite_f(&sVarf_MIumkn2g, VIf(Bf0));
    sEnv_process(this, &sEnv_BTHJuXP0, VIf(Bf5), &sEnv_BTHJuXP0_sendMessage);
    sEnv_process(this, &sEnv_QClAbQNf, VIf(I1), &sEnv_QClAbQNf_sendMessage);
    __hv_line_f(&sLine_8KwYBe3n, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_YUOKFyTx, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_OVB5kjyg, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_meABgQO2, VOf(Bf5));
    __hv_line_f(&sLine_L53NvMD7, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_IL6VBlRA, VIf(Bf2));
    __hv_varwrite_f(&sVarf_meABgQO2, VIf(Bf3));
    __hv_varwrite_f(&sVarf_ktkxsgr7, VIf(Bf6));
    __hv_varwrite_f(&sVarf_S1czfjv6, VIf(Bf1));
    __hv_varread_f(&sVarf_S1czfjv6, VOf(Bf1));
    __hv_line_f(&sLine_VBmjaAec, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_fHs753Nk, VIf(Bf3));
    __hv_varread_f(&sVarf_ktkxsgr7, VOf(Bf3));
    __hv_line_f(&sLine_3HbuJ7Ew, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_Q0267enL, VIf(Bf3));
    __hv_varwrite_f(&sVarf_fZFJzsT4, VIf(Bf0));
    __hv_varread_f(&sVarf_ScuV9jfA, VOf(Bf0));
    __hv_line_f(&sLine_w486z1oe, VOf(Bf3));
    __hv_varread_f(&sVarf_fZFJzsT4, VOf(Bf2));
    __hv_line_f(&sLine_Z0rjlaAc, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_5iDt6meW, VOf(Bf2));
    __hv_varread_f(&sVarf_2vLf1I5J, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
